@@ -1,14 +1,17 @@
-package Role::Commons::Authority;
-
+use 5.008;
 use strict;
 use warnings;
-use Moo::Role;
+
+package Role::Commons::Authority;
+
 use Carp qw[croak];
-use Scalar::Does qw[ does blessed CODE ARRAY HASH REGEXP STRING ];
+use match::simple qw[match];
+use Scalar::Util qw[blessed];
 
 BEGIN {
+	use Moo::Role;
 	$Role::Commons::Authority::AUTHORITY = 'cpan:TOBYINK';
-	$Role::Commons::Authority::VERSION   = '0.102';
+	$Role::Commons::Authority::VERSION   = '0.103';
 }
 
 our %ENABLE_SHARED;
@@ -21,37 +24,11 @@ our $setup_for_class = sub {
 	{
 		$ENABLE_SHARED{ $package } = 1;
 		
-		does($args{-authorities}, ARRAY) and
+		ref($args{-authorities}) eq 'ARRAY' and
 			$SHARED_AUTHORITIES{ $package } = $args{-authorities};
 	}
 };
 
-our $_smart_match;
-$_smart_match = sub
-{
-	my ($A, $B) = @_;
-	
-	if (not defined $B)
-		{ return not defined $A }
-	
-	if (does $B, CODE)
-		{ return $B->($A) }
-	
-	if (does $B, ARRAY)
-		{ return scalar grep { $_smart_match->($A, $_) } @$B }
-	
-	if (does $B, HASH)
-		{ return defined $A && exists $B->{$A} }
-	
-	if (does $B, REGEXP)
-		{ return $A =~ $B }
-	
-	if (does $B, STRING)
-		{ return $A eq $B }
-	
-	return;
-};
-
 sub AUTHORITY
 {
 	my ($invocant, $test) = @_;
@@ -73,7 +50,7 @@ sub AUTHORITY
 		my $ok = undef;
 		AUTH: for my $A (@authorities)
 		{
-			if ($_smart_match->($A, $test))
+			if (match($A, $test))
 			{
 				$ok = $A;
 				last AUTH;
@@ -197,7 +174,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2012 by Toby Inkster.
+This software is copyright (c) 2012, 2014 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
